/* 
 * This file is part of the Palacios Virtual Machine Monitor developed
 * by the V3VEE Project with funding from the United States National 
 * Science Foundation and the Department of Energy.  
 *
 * The V3VEE Project is a joint project between Northwestern University
 * and the University of New Mexico.  You can find out more at 
 * http://www.v3vee.org
 *
 * Copyright (c) 2011, Kyle C. Hale <kh@u.northwestern.edu> 
 * Copyright (c) 2011, The V3VEE Project <http://www.v3vee.org> 
 * All rights reserved.
 *
 * Author: Kyle C. Hale <kh@u.northwestern.edu>
 *
 * This is free software.  You are permitted to use,
 * redistribute, and modify it as specified in the file "V3VEE_LICENSE".
 */

#ifndef __SYSCALL_REF_H__
#define __SYSCALL_REF_H__



/* 32bit syscalls */
#define SYS32_RESTART_SYSCALL 0
#define SYS32_EXIT 1
#define SYS32_FORK 2
#define SYS32_READ 3
#define SYS32_WRITE 4
#define SYS32_OPEN 5
#define SYS32_CLOSE 6
#define SYS32_WAITPID 7
#define SYS32_CREAT 8
#define SYS32_LINK 9
#define SYS32_UNLINK 10
#define SYS32_EXECVE 11
#define SYS32_CHDIR 12
#define SYS32_TIME 13
#define SYS32_MKNOD 14
#define SYS32_CHMOD 15
#define SYS32_LCHOWN 16
#define SYS32_BREAK 17
#define SYS32_OLDSTAT 18
#define SYS32_LSEEK 19
#define SYS32_GETPID 20
#define SYS32_MOUNT 21
#define SYS32_UMOUNT 22
#define SYS32_SETUID 23
#define SYS32_GETUID 24
#define SYS32_STIME 25
#define SYS32_PTRACE 26
#define SYS32_ALARM 27
#define SYS32_OLDFSTAT 28
#define SYS32_PAUSE 29
#define SYS32_UTIME 30
#define SYS32_STTY 31
#define SYS32_GTTY 32
#define SYS32_ACCESS 33
#define SYS32_NICE 34
#define SYS32_FTIME 35
#define SYS32_SYNC 36
#define SYS32_KILL 37
#define SYS32_RENAME 38
#define SYS32_MKDIR 39
#define SYS32_RMDIR 40
#define SYS32_DUP 41
#define SYS32_PIPE 42
#define SYS32_TIMES 43
#define SYS32_PROF 44
#define SYS32_BRK 45
#define SYS32_SETGID 46
#define SYS32_GETGID 47
#define SYS32_SIGNAL 48
#define SYS32_GETEUID 49
#define SYS32_GETEGID 50
#define SYS32_ACCT 51
#define SYS32_UMOUNT2 52
#define SYS32_LOCK 53
#define SYS32_IOCTL 54
#define SYS32_FCNTL 55
#define SYS32_MPX 56
#define SYS32_SETPGID 57
#define SYS32_ULIMIT 58
#define SYS32_OLDOLDUNAME 59
#define SYS32_UMASK 60
#define SYS32_CHROOT 61
#define SYS32_USTAT 62
#define SYS32_DUP2 63
#define SYS32_GETPPID 64
#define SYS32_GETPGRP 65
#define SYS32_SETSID 66
#define SYS32_SIGACTION 67
#define SYS32_SGETMASK 68
#define SYS32_SSETMASK 69
#define SYS32_SETREUID 70
#define SYS32_SETREGID 71
#define SYS32_SIGSUSPEND 72
#define SYS32_SIGPENDING 73
#define SYS32_SETHOSTNAME 74
#define SYS32_SETRLIMIT 75
#define SYS32_GETRLIMIT 76
#define SYS32_GETRUSAGE 77
#define SYS32_GETTIMEOFDAY 78
#define SYS32_SETTIMEOFDAY 79
#define SYS32_GETGROUPS 80
#define SYS32_SETGROUPS 81
#define SYS32_SELECT 82
#define SYS32_SYMLINK 83
#define SYS32_OLDLSTAT 84
#define SYS32_READLINK 85
#define SYS32_USELIB 86
#define SYS32_SWAPON 87
#define SYS32_REBOOT 88
#define SYS32_READDIR 89
#define SYS32_MMAP 90
#define SYS32_MUNMAP 91
#define SYS32_TRUNCATE 92
#define SYS32_FTRUNCATE 93
#define SYS32_FCHMOD 94
#define SYS32_FCHOWN 95
#define SYS32_GETPRIORITY 96
#define SYS32_SETPRIORITY 97
#define SYS32_PROFIL 98
#define SYS32_STATFS 99
#define SYS32_FSTATFS 100
#define SYS32_IOPERM 101
#define SYS32_SOCKETCALL 102
#define SYS32_SYSLOG 103
#define SYS32_SETITIMER 104
#define SYS32_GETITIMER 105
#define SYS32_STAT 106
#define SYS32_LSTAT 107
#define SYS32_FSTAT 108
#define SYS32_OLDUNAME 109
#define SYS32_IOPL 110
#define SYS32_VHANGUP 111
#define SYS32_IDLE 112
#define SYS32_VM86OLD 113
#define SYS32_WAIT4 114
#define SYS32_SWAPOFF 115
#define SYS32_SYSINFO 116
#define SYS32_IPC 117
#define SYS32_FSYNC 118
#define SYS32_SIGRETURN 119
#define SYS32_CLONE 120
#define SYS32_SETDOMAINNAME 121
#define SYS32_UNAME 122
#define SYS32_MODIFY_LDT 123
#define SYS32_ADJTIMEX 124
#define SYS32_MPROTECT 125
#define SYS32_SIGPROCMASK 126
#define SYS32_CREATE_MODULE 127
#define SYS32_INIT_MODULE 128
#define SYS32_DELETE_MODULE 129
#define SYS32_GET_KERNEL_SYMS 130
#define SYS32_QUOTACTL 131
#define SYS32_GETPGID 132
#define SYS32_FCHDIR 133
#define SYS32_BDFLUSH 134
#define SYS32_SYSFS 135
#define SYS32_PERSONALITY 136
#define SYS32_AFS_SYSCALL 137
#define SYS32_SETFSUID 138
#define SYS32_SETFSGID 139
#define SYS32__LLSEEK 140
#define SYS32_GETDENTS 141
#define SYS32__NEWSELECT 142
#define SYS32_FLOCK 143
#define SYS32_MSYNC 144
#define SYS32_READV 145
#define SYS32_WRITEV 146
#define SYS32_GETSID 147
#define SYS32_FDATASYNC 148
#define SYS32__SYSCTL 149
#define SYS32_MLOCK 150
#define SYS32_MUNLOCK 151
#define SYS32_MLOCKALL 152
#define SYS32_MUNLOCKALL 153
#define SYS32_SCHED_SETPARAM 154
#define SYS32_SCHED_GETPARAM 155
#define SYS32_SCHED_SETSCHEDULER 156
#define SYS32_SCHED_GETSCHEDULER 157
#define SYS32_SCHED_YIELD 158
#define SYS32_SCHED_GET_PRIORITY_MAX 159
#define SYS32_SCHED_GET_PRIORITY_MIN 160
#define SYS32_SCHED_RR_GET_INTERVAL 161
#define SYS32_NANOSLEEP 162
#define SYS32_MREMAP 163
#define SYS32_SETRESUID 164
#define SYS32_GETRESUID 165
#define SYS32_VM86 166
#define SYS32_QUERY_MODULE 167
#define SYS32_POLL 168
#define SYS32_NFSSERVCTL 169
#define SYS32_SETRESGID 170
#define SYS32_GETRESGID 171
#define SYS32_PRCTL 172
#define SYS32_RT_SIGRETURN 173
#define SYS32_RT_SIGACTION 174
#define SYS32_RT_SIGPROCMASK 175
#define SYS32_RT_SIGPENDING 176
#define SYS32_RT_SIGTIMEDWAIT 177
#define SYS32_RT_SIGQUEUEINFO 178
#define SYS32_RT_SIGSUSPEND 179
#define SYS32_PREAD64 180
#define SYS32_PWRITE64 181
#define SYS32_CHOWN 182
#define SYS32_GETCWD 183
#define SYS32_CAPGET 184
#define SYS32_CAPSET 185
#define SYS32_SIGALTSTACK 186
#define SYS32_SENDFILE 187
#define SYS32_GETPMSG 188
#define SYS32_PUTPMSG 189
#define SYS32_VFORK 190
#define SYS32_UGETRLIMIT 191
#define SYS32_MMAP2 192
#define SYS32_TRUNCATE64 193
#define SYS32_FTRUNCATE64 194
#define SYS32_STAT64 195
#define SYS32_LSTAT64 196
#define SYS32_FSTAT64 197
#define SYS32_LCHOWN32 198
#define SYS32_GETUID32 199
#define SYS32_GETGID32 200
#define SYS32_GETEUID32 201
#define SYS32_GETEGID32 202
#define SYS32_SETREUID32 203
#define SYS32_SETREGID32 204
#define SYS32_GETGROUPS32 205
#define SYS32_SETGROUPS32 206
#define SYS32_FCHOWN32 207
#define SYS32_SETRESUID32 208
#define SYS32_GETRESUID32 209
#define SYS32_SETRESGID32 210
#define SYS32_GETRESGID32 211
#define SYS32_CHOWN32 212
#define SYS32_SETUID32 213
#define SYS32_SETGID32 214
#define SYS32_SETFSUID32 215
#define SYS32_SETFSGID32 216
#define SYS32_PIVOT_ROOT 217
#define SYS32_MINCORE 218
#define SYS32_MADVISE1 219
#define SYS32_GETDENTS64 220
#define SYS32_FCNTL64 221
#define SYS32_GETTID 224
#define SYS32_READAHEAD 225
#define SYS32_SETXATTR 226
#define SYS32_LSETXATTR 227
#define SYS32_FSETXATTR 228
#define SYS32_GETXATTR 229
#define SYS32_LGETXATTR 230
#define SYS32_FGETXATTR 231
#define SYS32_LISTXATTR 232
#define SYS32_LLISTXATTR 233
#define SYS32_FLISTXATTR 234
#define SYS32_REMOVEXATTR 235
#define SYS32_LREMOVEXATTR 236
#define SYS32_FREMOVEXATTR 237
#define SYS32_TKILL 238
#define SYS32_SENDFILE64 239
#define SYS32_FUTEX 240
#define SYS32_SCHED_SETAFFINITY 241
#define SYS32_SCHED_GETAFFINITY 242
#define SYS32_SET_THREAD_AREA 243
#define SYS32_GET_THREAD_AREA 244
#define SYS32_IO_SETUP 245
#define SYS32_IO_DESTROY 246
#define SYS32_IO_GETEVENTS 247
#define SYS32_IO_SUBMIT 248
#define SYS32_IO_CANCEL 249
#define SYS32_FADVISE64 250
#define SYS32_EXIT_GROUP 252
#define SYS32_LOOKUP_DCOOKIE 253
#define SYS32_EPOLL_CREATE 254
#define SYS32_EPOLL_CTL 255
#define SYS32_EPOLL_WAIT 256
#define SYS32_REMAP_FILE_PAGES 257
#define SYS32_SET_TID_ADDRESS 258
#define SYS32_TIMER_CREATE 259
#define SYS32_TIMER_SETTIME 260
#define SYS32_TIMER_GETTIME 261
#define SYS32_TIMER_GETOVERRUN 262
#define SYS32_TIMER_DELETE 263
#define SYS32_CLOCK_SETTIME 264
#define SYS32_CLOCK_GETTIME 265
#define SYS32_CLOCK_GETRES 266
#define SYS32_CLOCK_NANOSLEEP 267
#define SYS32_STATFS64 268
#define SYS32_FSTATFS64 269
#define SYS32_TGKILL 270
#define SYS32_UTIMES 271
#define SYS32_FADVISE64_64 272
#define SYS32_VSERVER 273
#define SYS32_MBIND 274
#define SYS32_GET_MEMPOLICY 275
#define SYS32_SET_MEMPOLICY 276
#define SYS32_MQ_OPEN 277
#define SYS32_MQ_UNLINK 278
#define SYS32_MQ_TIMEDSEND 279
#define SYS32_MQ_TIMEDRECEIVE 280
#define SYS32_MQ_NOTIFY 281
#define SYS32_MQ_GETSETATTR 282
#define SYS32_KEXEC_LOAD 283
#define SYS32_WAITID 284
#define SYS32_SYS32_SETALTROOT 285
#define SYS32_ADD_KEY 286
#define SYS32_REQUEST_KEY 287
#define SYS32_KEYCTL 288
#define SYS32_IOPRIO_SET 289
#define SYS32_IOPRIO_GET 290
#define SYS32_INOTIFY_INIT 291
#define SYS32_INOTIFY_ADD_WATCH 292
#define SYS32_INOTIFY_RM_WATCH 293
#define SYS32_MIGRATE_PAGES 294
#define SYS32_OPENAT 295
#define SYS32_MKDIRAT 296
#define SYS32_MKNODAT 297
#define SYS32_FCHOWNAT 298
#define SYS32_FUTIMESAT 299
#define SYS32_FSTATAT64 300
#define SYS32_UNLINKAT 301
#define SYS32_RENAMEAT 302
#define SYS32_LINKAT 303
#define SYS32_SYMLINKAT 304
#define SYS32_READLINKAT 305
#define SYS32_FCHMODAT 306
#define SYS32_FACCESSAT 307
#define SYS32_PSELECT6 308
#define SYS32_PPOLL 309
#define SYS32_UNSHARE 310
#define SYS32_SET_ROBUST_LIST 311
#define SYS32_GET_ROBUST_LIST 312
#define SYS32_SPLICE 313
#define SYS32_SYNC_FILE_RANGE 314
#define SYS32_TEE 315
#define SYS32_VMSPLICE 316
#define SYS32_MOVE_PAGES 317
#define SYS32_GETCPU 318
#define SYS32_EPOLL_PWAIT 319
#define SYS32_UTIMENSAT 320
#define SYS32_SIGNALFD 321
#define SYS32_TIMERFD_CREATE 322
#define SYS32_EVENTFD 323
#define SYS32_FALLOCATE 324
#define SYS32_TIMERFD_SETTIME 325
#define SYS32_TIMERFD_GETTIME 326
#define SYS32_SIGNALFD4 327
#define SYS32_EVENTFD2 328
#define SYS32_EPOLL_CREATE1 329
#define SYS32_DUP3 330
#define SYS32_PIPE2 331
#define SYS32_INOTIFY_INIT1 332
#define SYS32_PREADV 333
#define SYS32_PWRITEV 334
#define SYS32_RT_TGSIGQUEUEINFO 335
#define SYS32_PERF_EVENT_OPEN 336

/* 64bit syscalls */
#define SYS64_READ 0
#define SYS64_WRITE 1
#define SYS64_OPEN 2
#define SYS64_CLOSE 3
#define SYS64_STAT 4
#define SYS64_FSTAT 5
#define SYS64_LSTAT 6
#define SYS64_POLL 7
#define SYS64_LSEEK 8
#define SYS64_MMAP 9
#define SYS64_MPROTECT 10
#define SYS64_MUNMAP 11
#define SYS64_BRK 12
#define SYS64_RT_SIGACTION 13
#define SYS64_RT_SIGPROCMASK 14
#define SYS64_RT_SIGRETURN 15
#define SYS64_IOCTL 16
#define SYS64_PREAD64 17
#define SYS64_PWRITE64 18
#define SYS64_READV 19
#define SYS64_WRITEV 20
#define SYS64_ACCESS 21
#define SYS64_PIPE 22
#define SYS64_SELECT 23
#define SYS64_SCHED_YIELD 24
#define SYS64_MREMAP 25
#define SYS64_MSYNC 26
#define SYS64_MINCORE 27
#define SYS64_MADVISE 28
#define SYS64_SHMGET 29
#define SYS64_SHMAT 30
#define SYS64_SHMCTL 31
#define SYS64_DUP 32
#define SYS64_DUP2 33
#define SYS64_PAUSE 34
#define SYS64_NANOSLEEP 35
#define SYS64_GETITIMER 36
#define SYS64_ALARM 37
#define SYS64_SETITIMER 38
#define SYS64_GETPID 39
#define SYS64_SENDFILE 40
#define SYS64_SOCKET 41
#define SYS64_CONNECT 42
#define SYS64_ACCEPT 43
#define SYS64_SENDTO 44
#define SYS64_RECVFROM 45
#define SYS64_SENDMSG 46
#define SYS64_RECVMSG 47
#define SYS64_SHUTDOWN 48
#define SYS64_BIND 49
#define SYS64_LISTEN 50
#define SYS64_GETSOCKNAME 51
#define SYS64_GETPEERNAME 52
#define SYS64_SOCKETPAIR 53
#define SYS64_SETSOCKOPT 54
#define SYS64_GETSOCKOPT 55
#define SYS64_CLONE 56
#define SYS64_FORK 57
#define SYS64_VFORK 58
#define SYS64_EXECVE 59
#define SYS64_EXIT 60
#define SYS64_WAIT4 61
#define SYS64_KILL 62
#define SYS64_UNAME 63
#define SYS64_SEMGET 64
#define SYS64_SEMOP 65
#define SYS64_SEMCTL 66
#define SYS64_SHMDT 67
#define SYS64_MSGGET 68
#define SYS64_MSGSND 69
#define SYS64_MSGRCV 70
#define SYS64_MSGCTL 71
#define SYS64_FCNTL 72
#define SYS64_FLOCK 73
#define SYS64_FSYNC 74
#define SYS64_FDATASYNC 75
#define SYS64_TRUNCATE 76
#define SYS64_FTRUNCATE 77
#define SYS64_GETDENTS 78
#define SYS64_GETCWD 79
#define SYS64_CHDIR 80
#define SYS64_FCHDIR 81
#define SYS64_RENAME 82
#define SYS64_MKDIR 83
#define SYS64_RMDIR 84
#define SYS64_CREAT 85
#define SYS64_LINK 86
#define SYS64_UNLINK 87
#define SYS64_SYMLINK 88
#define SYS64_READLINK 89
#define SYS64_CHMOD 90
#define SYS64_FCHMOD 91
#define SYS64_CHOWN 92
#define SYS64_FCHOWN 93
#define SYS64_LCHOWN 94
#define SYS64_UMASK 95
#define SYS64_GETTIMEOFDAY 96
#define SYS64_GETRLIMIT 97
#define SYS64_GETRUSAGE 98
#define SYS64_SYSINFO 99
#define SYS64_TIMES 100
#define SYS64_PTRACE 101
#define SYS64_GETUID 102
#define SYS64_SYSLOG 103
#define SYS64_GETGID 104
#define SYS64_SETUID 105
#define SYS64_SETGID 106
#define SYS64_GETEUID 107
#define SYS64_GETEGID 108
#define SYS64_SETPGID 109
#define SYS64_GETPPID 110
#define SYS64_GETPGRP 111
#define SYS64_SETSID 112
#define SYS64_SETREUID 113
#define SYS64_SETREGID 114
#define SYS64_GETGROUPS 115
#define SYS64_SETGROUPS 116
#define SYS64_SETRESUID 117
#define SYS64_GETRESUID 118
#define SYS64_SETRESGID 119
#define SYS64_GETRESGID 120
#define SYS64_GETPGID 121
#define SYS64_SETFSUID 122
#define SYS64_SETFSGID 123
#define SYS64_GETSID 124
#define SYS64_CAPGET 125
#define SYS64_CAPSET 126
#define SYS64_RT_SIGPENDING 127
#define SYS64_RT_SIGTIMEDWAIT 128
#define SYS64_RT_SIGQUEUEINFO 129
#define SYS64_RT_SIGSUSPEND 130
#define SYS64_SIGALTSTACK 131
#define SYS64_UTIME 132
#define SYS64_MKNOD 133
#define SYS64_USELIB 134
#define SYS64_PERSONALITY 135
#define SYS64_USTAT 136
#define SYS64_STATFS 137
#define SYS64_FSTATFS 138
#define SYS64_SYSFS 139
#define SYS64_GETPRIORITY 140
#define SYS64_SETPRIORITY 141
#define SYS64_SCHED_SETPARAM 142
#define SYS64_SCHED_GETPARAM 143
#define SYS64_SCHED_SETSCHEDULER 144
#define SYS64_SCHED_GETSCHEDULER 145
#define SYS64_SCHED_GET_PRIORITY_MAX 146
#define SYS64_SCHED_GET_PRIORITY_MIN 147
#define SYS64_SCHED_RR_GET_INTERVAL 148
#define SYS64_MLOCK 149
#define SYS64_MUNLOCK 150
#define SYS64_MLOCKALL 151
#define SYS64_MUNLOCKALL 152
#define SYS64_VHANGUP 153
#define SYS64_MODIFY_LDT 154
#define SYS64_PIVOT_ROOT 155
#define SYS64__SYSCTL 156
#define SYS64_PRCTL 157
#define SYS64_ARCH_PRCTL 158
#define SYS64_ADJTIMEX 159
#define SYS64_SETRLIMIT 160
#define SYS64_CHROOT 161
#define SYS64_SYNC 162
#define SYS64_ACCT 163
#define SYS64_SETTIMEOFDAY 164
#define SYS64_MOUNT 165
#define SYS64_UMOUNT2 166
#define SYS64_SWAPON 167
#define SYS64_SWAPOFF 168
#define SYS64_REBOOT 169
#define SYS64_SETHOSTNAME 170
#define SYS64_SETDOMAINNAME 171
#define SYS64_IOPL 172
#define SYS64_IOPERM 173
#define SYS64_CREATE_MODULE 174
#define SYS64_INIT_MODULE 175
#define SYS64_DELETE_MODULE 176
#define SYS64_GET_KERNEL_SYMS 177
#define SYS64_QUERY_MODULE 178
#define SYS64_QUOTACTL 179
#define SYS64_NFSSERVCTL 180
#define SYS64_GETPMSG 181
#define SYS64_PUTPMSG 182
#define SYS64_AFS_SYSCALL 183
#define SYS64_TUXCALL 184
#define SYS64_SECURITY 185
#define SYS64_GETTID 186
#define SYS64_READAHEAD 187
#define SYS64_SETXATTR 188
#define SYS64_LSETXATTR 189
#define SYS64_FSETXATTR 190
#define SYS64_GETXATTR 191
#define SYS64_LGETXATTR 192
#define SYS64_FGETXATTR 193
#define SYS64_LISTXATTR 194
#define SYS64_LLISTXATTR 195
#define SYS64_FLISTXATTR 196
#define SYS64_REMOVEXATTR 197
#define SYS64_LREMOVEXATTR 198
#define SYS64_FREMOVEXATTR 199
#define SYS64_TKILL 200
#define SYS64_TIME 201
#define SYS64_FUTEX 202
#define SYS64_SCHED_SETAFFINITY 203
#define SYS64_SCHED_GETAFFINITY 204
#define SYS64_SET_THREAD_AREA 205
#define SYS64_IO_SETUP 206
#define SYS64_IO_DESTROY 207
#define SYS64_IO_GETEVENTS 208
#define SYS64_IO_SUBMIT 209
#define SYS64_IO_CANCEL 210
#define SYS64_GET_THREAD_AREA 211
#define SYS64_LOOKUP_DCOOKIE 212
#define SYS64_EPOLL_CREATE 213
#define SYS64_EPOLL_CTL_OLD 214
#define SYS64_EPOLL_WAIT_OLD 215
#define SYS64_REMAP_FILE_PAGES 216
#define SYS64_GETDENTS64 217
#define SYS64_SET_TID_ADDRESS 218
#define SYS64_RESTART_SYSCALL 219
#define SYS64_SEMTIMEDOP 220
#define SYS64_FADVISE64 221
#define SYS64_TIMER_CREATE 222
#define SYS64_TIMER_SETTIME 223
#define SYS64_TIMER_GETTIME 224
#define SYS64_TIMER_GETOVERRUN 225
#define SYS64_TIMER_DELETE 226
#define SYS64_CLOCK_SETTIME 227
#define SYS64_CLOCK_GETTIME 228
#define SYS64_CLOCK_GETRES 229
#define SYS64_CLOCK_NANOSLEEP 230
#define SYS64_EXIT_GROUP 231
#define SYS64_EPOLL_WAIT 232
#define SYS64_EPOLL_CTL 233
#define SYS64_TGKILL 234
#define SYS64_UTIMES 235
#define SYS64_VSERVER 236
#define SYS64_MBIND 237
#define SYS64_SET_MEMPOLICY 238
#define SYS64_GET_MEMPOLICY 239
#define SYS64_MQ_OPEN 240
#define SYS64_MQ_UNLINK 241
#define SYS64_MQ_TIMEDSEND 242
#define SYS64_MQ_TIMEDRECEIVE 243
#define SYS64_MQ_NOTIFY 244
#define SYS64_MQ_GETSETATTR 245
#define SYS64_KEXEC_LOAD 246
#define SYS64_WAITID 247
#define SYS64_ADD_KEY 248
#define SYS64_REQUEST_KEY 249
#define SYS64_KEYCTL 250
#define SYS64_IOPRIO_SET 251
#define SYS64_IOPRIO_GET 252
#define SYS64_INOTIFY_INIT 253
#define SYS64_INOTIFY_ADD_WATCH 254
#define SYS64_INOTIFY_RM_WATCH 255
#define SYS64_MIGRATE_PAGES 256
#define SYS64_OPENAT 257
#define SYS64_MKDIRAT 258
#define SYS64_MKNODAT 259
#define SYS64_FCHOWNAT 260
#define SYS64_FUTIMESAT 261
#define SYS64_NEWFSTATAT 262
#define SYS64_UNLINKAT 263
#define SYS64_RENAMEAT 264
#define SYS64_LINKAT 265
#define SYS64_SYMLINKAT 266
#define SYS64_READLINKAT 267
#define SYS64_FCHMODAT 268
#define SYS64_FACCESSAT 269
#define SYS64_PSELECT6 270
#define SYS64_PPOLL 271
#define SYS64_UNSHARE 272
#define SYS64_SET_ROBUST_LIST 273
#define SYS64_GET_ROBUST_LIST 274
#define SYS64_SPLICE 275
#define SYS64_TEE 276
#define SYS64_SYNC_FILE_RANGE 277
#define SYS64_VMSPLICE 278
#define SYS64_MOVE_PAGES 279
#define SYS64_UTIMENSAT 280
#define SYS64_EPOLL_PWAIT 281
#define SYS64_SIGNALFD 282
#define SYS64_TIMERFD_CREATE 283
#define SYS64_EVENTFD 284
#define SYS64_FALLOCATE 285
#define SYS64_TIMERFD_SETTIME 286
#define SYS64_TIMERFD_GETTIME 287
#define SYS64_ACCEPT4 288
#define SYS64_SIGNALFD4 289
#define SYS64_EVENTFD2 290
#define SYS64_EPOLL_CREATE1 291
#define SYS64_DUP3 292
#define SYS64_PIPE2 293
#define SYS64_INOTIFY_INIT1 294
#define SYS64_PREADV 295
#define SYS64_PWRITEV 296
#define SYS64_RT_TGSIGQUEUEINFO 297
#define SYS64_PERF_EVENT_OPEN 298


#endif
